@@ -44,10 +44,14 @@ fn main() {
 	info!("Starting build");
 	let start = Instant::now();
 	let mut sh = Shtola::new();
-	sh.source(args.source);
+	sh.source(&args.source);
 	sh.destination(args.destination);
 	sh.clean(args.clean);
 	sh.frontmatter(!args.frontmatter);
+	let potential_gitignore = args.source.join(".gitignore");
+	if potential_gitignore.exists() {
+		sh.source_ignores(&potential_gitignore).unwrap();
+	}
 	if !args.ignored_plugins.contains(&"tera_layouts".to_string()) {
 		sh.register(plugins::tera_layouts::plugin());
 	}
